@@ -8,7 +8,7 @@ package Devel::MAT::SV;
 use strict;
 use warnings;
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -88,6 +88,14 @@ C<Devel::MAT::SV::> prefix.
 
 =cut
 
+=head2 basetype
+
+   $type = $sv->basetype
+
+Returns the inner perl API type of the SV. This is one of
+
+   SV AV HV CV GV LV PVIO PVFM REGEXP INVLIST
+
 =head2 desc
 
    $desc = $sv->desc
@@ -414,8 +422,9 @@ boolean true and false. They are
 
 package Devel::MAT::SV::Immortal;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 use constant immortal => 1;
+use constant basetype => "SV";
 sub new {
    my $class = shift;
    my ( $df, $addr ) = @_;
@@ -427,13 +436,13 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::UNDEF;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 sub desc { "UNDEF" }
 sub type { "UNDEF" }
 
 package Devel::MAT::SV::YES;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 sub desc { "YES" }
 sub type { "SCALAR" }
 
@@ -447,7 +456,7 @@ sub is_weak { '' }
 
 package Devel::MAT::SV::NO;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 sub desc { "NO" }
 sub type { "SCALAR" }
 
@@ -461,7 +470,7 @@ sub is_weak { '' }
 
 package Devel::MAT::SV::Unknown;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 __PACKAGE__->register_type( 0xff );
 
 sub desc { "UNKNOWN" }
@@ -470,9 +479,10 @@ sub _outrefs {}
 
 package Devel::MAT::SV::GLOB;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 __PACKAGE__->register_type( 1 );
 use constant $CONSTANTS;
+use constant basetype => "GV";
 
 =head1 Devel::MAT::SV::GLOB
 
@@ -640,9 +650,10 @@ sub _outrefs
 
 package Devel::MAT::SV::SCALAR;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 __PACKAGE__->register_type( 2 );
 use constant $CONSTANTS;
+use constant basetype => "SV";
 
 =head1 Devel::MAT::SV::SCALAR
 
@@ -801,9 +812,10 @@ sub _outrefs
 
 package Devel::MAT::SV::REF;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 __PACKAGE__->register_type( 3 );
 use constant $CONSTANTS;
+use constant basetype => "SV";
 
 =head1 Devel::MAT::SV::REF
 
@@ -892,9 +904,10 @@ sub _outrefs
 
 package Devel::MAT::SV::ARRAY;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 __PACKAGE__->register_type( 4 );
 use constant $CONSTANTS;
+use constant basetype => "AV";
 
 =head1 Devel::MAT::SV::ARRAY
 
@@ -1033,7 +1046,7 @@ sub _outrefs
 package Devel::MAT::SV::PADLIST;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 use constant type => "PADLIST";
 use constant $CONSTANTS;
 
@@ -1082,7 +1095,7 @@ sub _outrefs
 package Devel::MAT::SV::PADNAMES;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 use constant type => "PADNAMES";
 use constant $CONSTANTS;
 
@@ -1166,7 +1179,7 @@ sub _outrefs
 package Devel::MAT::SV::PAD;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 use constant type => "PAD";
 use constant $CONSTANTS;
 
@@ -1259,9 +1272,10 @@ sub _outrefs
 
 package Devel::MAT::SV::HASH;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 __PACKAGE__->register_type( 5 );
 use constant $CONSTANTS;
+use constant basetype => "HV";
 
 =head1 Devel::MAT::SV::HASH
 
@@ -1420,7 +1434,7 @@ sub _outrefs
 
 package Devel::MAT::SV::STASH;
 use base qw( Devel::MAT::SV::HASH );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 __PACKAGE__->register_type( 6 );
 use constant $CONSTANTS;
 
@@ -1560,9 +1574,10 @@ sub _outrefs
 
 package Devel::MAT::SV::CODE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 __PACKAGE__->register_type( 7 );
 use constant $CONSTANTS;
+use constant basetype => "CV";
 
 use Carp;
 
@@ -2078,9 +2093,10 @@ sub _outrefs
 
 package Devel::MAT::SV::IO;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 __PACKAGE__->register_type( 8 );
 use constant $CONSTANTS;
+use constant basetype => "IO";
 
 =head1 Devel::MAT::SV::IO
 
@@ -2152,9 +2168,10 @@ sub _outrefs
 
 package Devel::MAT::SV::LVALUE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 __PACKAGE__->register_type( 9 );
 use constant $CONSTANTS;
+use constant basetype => "LV";
 
 sub load
 {
@@ -2193,7 +2210,8 @@ sub _outrefs
 
 package Devel::MAT::SV::REGEXP;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
+use constant basetype => "REGEXP";
 __PACKAGE__->register_type( 10 );
 
 sub load {}
@@ -2204,7 +2222,8 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::FORMAT;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
+use constant basetype => "PVFM";
 __PACKAGE__->register_type( 11 );
 
 sub load {}
@@ -2215,7 +2234,8 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::INVLIST;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.36';
+our $VERSION = '0.37';
+use constant basetype => "INVLIST";
 __PACKAGE__->register_type( 12 );
 
 sub load {}
@@ -2224,6 +2244,24 @@ sub desc { "INVLIST()" }
 
 sub _outrefs { () }
 
+# A hack to compress files
+package Devel::MAT::SV::_UNDEFSV;
+use base qw( Devel::MAT::SV::SCALAR );
+our $VERSION = '0.37';
+__PACKAGE__->register_type( 13 );
+
+sub load
+{
+   my $self = shift;
+
+   bless $self, "Devel::MAT::SV::SCALAR";
+
+   $self->_set_scalar_fields( 0, 0, 0,
+      "", 0,
+      0,
+   );
+}
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
